"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.copyArrayBuffer = exports.isUint8Array = exports.isArrayBuffer = exports.str2ab = exports.ab2str = exports.isObjectAndNotNull = exports.newBinary = exports.quote = exports.handleError = exports.checkError = exports.isInfOrNaN = exports.isArguments = exports.convertMapToObject = exports.hasOwn = exports.lengthOf = exports.keysOf = exports.isObject = exports.isFunction = void 0;
const isFunction = fn => typeof fn === 'function';
exports.isFunction = isFunction;
const isObject = fn => typeof fn === 'object';
exports.isObject = isObject;
const keysOf = obj => Object.keys(obj);
exports.keysOf = keysOf;
const lengthOf = obj => Object.keys(obj).length;
exports.lengthOf = lengthOf;
const hasOwn = (obj, prop) => Object.prototype.hasOwnProperty.call(obj, prop);
exports.hasOwn = hasOwn;
const convertMapToObject = map => Array.from(map).reduce((acc, [key, value]) => {
    // reassign to not create new object
    acc[key] = value;
    return acc;
}, {});
exports.convertMapToObject = convertMapToObject;
const isArguments = obj => obj != null && (0, exports.hasOwn)(obj, 'callee');
exports.isArguments = isArguments;
const isInfOrNaN = obj => Number.isNaN(obj) || obj === Infinity || obj === -Infinity;
exports.isInfOrNaN = isInfOrNaN;
exports.checkError = {
    maxStack: msgError => new RegExp('Maximum call stack size exceeded', 'g').test(msgError),
};
const handleError = fn => function (...args) {
    try {
        return fn.apply(this, args);
    }
    catch (error) {
        const isMaxStack = exports.checkError.maxStack(error.message);
        if (isMaxStack) {
            throw new Error('Converting circular structure to JSON');
        }
        throw error;
    }
};
exports.handleError = handleError;
const quote = string => {
    return JSON.stringify(string);
};
exports.quote = quote;
const newBinary = (len) => {
    return new Uint8Array(new ArrayBuffer(len));
};
exports.newBinary = newBinary;
const isObjectAndNotNull = obj => obj !== null && typeof obj === 'object';
exports.isObjectAndNotNull = isObjectAndNotNull;
function ab2str(buf) {
    return String.fromCharCode.apply(null, new Uint16Array(buf));
}
exports.ab2str = ab2str;
function str2ab(str) {
    const buf = new ArrayBuffer(str.length * 2); // 2 bytes for each char
    const bufView = new Uint16Array(buf);
    for (let i = 0, strLen = str.length; i < strLen; i++) {
        bufView[i] = str.charCodeAt(i);
    }
    return buf;
}
exports.str2ab = str2ab;
const isArrayBuffer = obj => {
    return obj instanceof ArrayBuffer;
};
exports.isArrayBuffer = isArrayBuffer;
const isUint8Array = obj => {
    return obj instanceof Uint8Array;
};
exports.isUint8Array = isUint8Array;
const copyArrayBuffer = src => {
    const dst = new ArrayBuffer(src.byteLength);
    new Uint8Array(dst).set(new Uint8Array(src));
    return dst;
};
exports.copyArrayBuffer = copyArrayBuffer;
//# sourceMappingURL=utils.js.map